# -*- mode: rpm-spec; indent-tabs-mode: nil -*-
#========================================================================
%global debug_package %{nil}

%define    basename_   ldas-tools-frameAPI
%define    name        %{basename_}-swig
%define    name_desc   frame utility
%define    hdr_dir     frameAPI
%define    tarbasename ldas-tools-frameAPI-swig
%define    version     2.6.10
%define    release     1
%define    _docdir     %{_datadir}/doc/%{name}-%{version}

%define check_cmake3  ( 0%{?rhel} && 0%{?rhel} <= 7 )
%define check_python2 ( 0%{?rhel} && 0%{?rhel} <= 7 )
%define check_python3 ( 0%{?__python3:1} || ( 0%{?rhel} >= 7 ) )

#------------------------------------------------------------------------
Name:      %{name}
Summary:   SWIG bindings for LDAS Tools frame utility library
Version:   %{version}
Release:   %{release}%{?dist}
License:   GPLv2+
URL:       "https://wiki.ligo.org/Computing/LDASTools"
Group:     Application/Scientific
Provides:  %{name} = %{version}
Obsoletes: %{name} < %{version}
Conflicts: %{basename_}-devel < 2.6.0
Prefix:    %_prefix
BuildRoot: %{buildroot}
Source0:   https://software.igwn.org/lscsoft/source/%{tarbasename}-%{version}.tar.gz
#------------------------------------------------------------------------
%if %{check_cmake3}
BuildRequires: cmake3 >= 3.6
BuildRequires: cmake
%else
BuildRequires: cmake >= 3.6
%endif
BuildRequires: python3-rpm-macros
BuildRequires: gawk
BuildRequires: gcc, gcc-c++, glibc
BuildRequires: make
Buildrequires: ldas-tools-cmake >= 1.2.3
Buildrequires: %{basename_}-devel >= 2.6.6
Buildrequires: pkgconfig
BuildRequires: rpm-build
BuildRequires: swig
BuildRequires: ldas-tools-al-swig >= 2.6.9
BuildRequires: ldas-tools-framecpp-swig >= 2.6.12
BuildRequires: ldas-tools-ldasgen-swig >= 2.6.9
#........................................................................
# Python dependencies
#........................................................................
%if %check_python2
BuildRequires: python2
BuildRequires: python2-devel
BuildRequires: python2-ldas-tools-framecpp >= 2.6.12
BuildRequires: python2-ldas-tools-ldasgen >= 2.6.9
%endif
#........................................................................
# Python 3 dependencies
#........................................................................
%if %check_python3
BuildRequires: python3
BuildRequires: python3-libs
BuildRequires: python3-devel
BuildRequires: python%{python3_pkgversion}-ldas-tools-framecpp >= 2.6.12
BuildRequires: python%{python3_pkgversion}-ldas-tools-ldasgen >= 2.6.9
%endif
#........................................................................
# Runtime dependencies
#........................................................................
Requires: swig
Requires: ldas-tools-framecpp-swig >= 2.6.12
Requires: ldas-tools-ldasgen-swig >= 2.6.9
Requires: %{basename_}-devel >= 2.6.6

%description


#========================================================================
%if %check_python2
%package -n python2-%{basename_}
Summary: LDAS Tools %{name_desc} toolkit python %{python2_version} bindings
#........................................................................
# Runtime dependencies
#........................................................................
Requires: python2-ldas-tools-framecpp >= 2.6.12
Requires: python2-ldas-tools-ldasgen >= 2.6.9
Requires: %{basename_} >= 2.6.6
Obsoletes: %{basename_}-python < %{version}

%description -n  python2-%{basename_}
This provides the python%{python2_version} bindings for the %{name_desc} library
%endif

#========================================================================
%if %check_python3
%package -n python%{python3_pkgversion}-%{basename_}
Summary: LDAS Tools %{name_desc} toolkit python %{python3_version} bindings
#........................................................................
# Runtime dependencies
#........................................................................
Requires: python%{python3_pkgversion}-ldas-tools-framecpp >= 2.6.12
Requires: python%{python3_pkgversion}-ldas-tools-ldasgen >= 2.6.9
Requires: %{basename_} >= 2.6.6

%description -n  python%{python3_pkgversion}-%{basename_}
This provides the python%{python3_version} bindings for the %{name_desc} library
%endif

#========================================================================

%prep
%setup -c -T -D -a 0 -n %{name}-%{version}

%build
%if %check_python2
export PYTHON2_BUILD_OPTS="-DENABLE_SWIG_PYTHON2=YES -DPYTHON2_EXECUTABLE=%{__python2}"
%else
export PYTHON2_BUILD_OPTS="-DENABLE_SWIG_PYTHON2=NO"
%endif
%if %check_python3
export PYTHON3_BUILD_OPTS="-DENABLE_SWIG_PYTHON3=YES -DPYTHON3_EXECUTABLE=%{__python3}"
%else
export PYTHON3_BUILD_OPTS="-DENABLE_SWIG_PYTHON3=NO"
%endif

%if %{check_cmake3}
export CMAKE_PROGRAM=cmake3
%else
export CMAKE_PROGRAM=cmake
%endif

${CMAKE_PROGRAM} \
    ${PYTHON2_BUILD_OPTS} \
    ${PYTHON3_BUILD_OPTS} \
    -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_EXPORT_COMPILE_COMMANDS=1 \
    -DCMAKE_INSTALL_PREFIX=%{_prefix} \
    -DCMAKE_INSTALL_DOCDIR=%{_docdir} \
    %{tarbasename}-%{version}

%install
make install DESTDIR=%{buildroot}
rm -f %{buildroot}%{_docdir}/README

%check
%if %{check_cmake3}
export CTEST_PROGRAM=ctest3
%else
export CTEST_PROGRAM=ctest
%endif
${CTEST_PROGRAM} -V %{?_smp_mflags}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%{_includedir}/%{hdr_dir}/*.i

%if %check_python2
%files -n python2-%{basename_}
%defattr(-,root,root,-)
%{_libdir}/python2*
%endif

%if %check_python3
%files -n python%{python3_pkgversion}-%{basename_}
%defattr(-,root,root,-)
%{_libdir}/python3*
%endif

%changelog
* Wed Sep 29 2021 Edward Maros <ed.maros@ligo.org> - 2.6.10-1
- Built for new release

* Tue Mar 9 2021 Edward Maros <ed.maros@ligo.org> - 2.6.9-1
- Built for new release

* Wed Aug 14 2019 Edward Maros <ed.maros@ligo.org> - 2.6.8-1
- Built for new release

* Thu Dec 06 2018 Edward Maros <ed.maros@ligo.org> - 2.6.7-1
- Built for new release

* Tue Nov 27 2018 Edward Maros <ed.maros@ligo.org> - 2.6.6-1
- Built for new release

* Tue Oct 11 2011 Edward Maros <emaros@ligo.caltech.edu> - 1.19.13-1
- Initial build.
